diff core/RTAudioCommandLine.cpp @ 301:e4392164b458 prerelease

RENAMED BeagleRT to Bela AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA, scripts probably not working
author Giulio Moro <giuliomoro@yahoo.it>
date Fri, 27 May 2016 14:34:41 +0100
parents c55c6f6c233c
children bfcbeb437869
line wrap: on
line diff
--- a/core/RTAudioCommandLine.cpp	Fri May 27 13:58:20 2016 +0100
+++ b/core/RTAudioCommandLine.cpp	Fri May 27 14:34:41 2016 +0100
@@ -9,7 +9,7 @@
 #include <cstdlib>
 #include <cstring>
 #include <getopt.h>
-#include "../include/BeagleRT.h"
+#include "../include/Bela.h"
 
 #define OPT_PRU_FILE 1000
 #define OPT_PGA_GAIN_LEFT 1001
@@ -46,8 +46,8 @@
 
 const char gDefaultShortOptions[] = "p:vN:M:C:D:A:H:G:B:R:T:S:";
 
-// This function sets the default settings for the BeagleRTInitSettings structure
-void BeagleRT_defaultSettings(BeagleRTInitSettings *settings)
+// This function sets the default settings for the BelaInitSettings structure
+void Bela_defaultSettings(BelaInitSettings *settings)
 {
 	// Set default values for settings
 	settings->periodSize = 16;
@@ -87,7 +87,7 @@
 // be stored in settings, otherwise arguments will be returned
 // as getopt() normally does.
 
-int BeagleRT_getopt_long(int argc, char *argv[], const char *customShortOptions, const struct option *customLongOptions, BeagleRTInitSettings *settings)
+int Bela_getopt_long(int argc, char *argv[], const char *customShortOptions, const struct option *customLongOptions, BelaInitSettings *settings)
 {
 	static int firstRun = 1;
 	static char totalShortOptions[256];
@@ -244,7 +244,7 @@
 
 // This function prints standard usage information for default arguments
 // Call from within your own usage function
-void BeagleRT_usage()
+void Bela_usage()
 {
 	std::cerr << "   --period [-p] period:            Set the hardware period (buffer) size in analog samples\n";
 	std::cerr << "   --dac-level [-D] dBs:            Set the DAC output level (0dB max; -63.5dB min)\n";